( cd usr/bin ; rm -rf cc )
( cd usr/bin ; ln -sf gcc cc )
( cd usr/lib ; rm -rf libgcc_s.so )
( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/lib ; rm -rf libgomp.so )
( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so )
( cd usr/lib ; rm -rf libgomp.so.1 )
( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so.1 )
( cd usr/lib/gcc/i586-pc-linux/4.3.3/include-fixed ; rm -rf X11 )
( cd usr/lib/gcc/i586-pc-linux/4.3.3/include-fixed ; ln -sf root/usr/X11R7/include/X11 X11 )
